FilePickerz class

Constructors

FilePickerz()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

clearTemporaryFiles() → dynamic
getDirectoryPath({String? dialogTitle, bool lockParentWindow = false, String? initialDirectory}) Future<String?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
pickFiles({FileType type = FileType.any, List<String>? allowedExtensions, String? dialogTitle, String? initialDirectory, dynamic onFileLoading(FilePickerStatus)?, bool? allowCompression = true, bool allowMultiple = false, bool? withData = false, bool? withReadStream = false, bool lockParentWindow = false}) Future<FilePickerResult?>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited