MethodChannelFilePickerz class

Inheritance

Constructors

MethodChannelFilePickerz()

Properties

eventChannel EventChannel
final
hashCode int
The hash code for this object.
no setterinherited
methodChannel MethodChannel
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

clearTemporaryFiles() Future<bool?>
override
getDirectoryPath(String dialogTitle, bool lockParentWindow, String initialDirectory) Future<String?>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
pickFiles(FileType type, List<String>? allowedExtensions, String? dialogTitle, String? initialDirectory, dynamic onFileLoading(FilePickerStatus p1)?, bool? allowCompression, bool allowMultiple, bool? withData, bool? withReadStream, bool lockParentWindow) Future<FilePickerResult?>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited